#
# spec file for package owncloud-client
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
%if 0%{?suse_version} == 1110
# SLES 11 calls make_install makeinstall
%define make_install %{makeinstall}
%endif
# We need a more recent, prefixed Qt for SLE11
%define qtprefix opt-
%define _prefix /opt/qt-4.8
%define cmake_args -DCMAKE_INCLUDE_PATH=%{_prefix}/include -DCMAKE_LIBRARY_PATH=%{_prefix}/lib64
%else
%define qtprefix %{nil} 
%define cmake_args%{nil} 
%endif

Name:           owncloud-client
Version:        1.4.2
Release:        1.3
License:        GPL-2.0+
Summary:        The ownCloud Client - Private file sync and share client based on Mirall
Url:            https://www.github.com/owncloud/mirall/
Group:          Productivity/Networking/Other
Source0:        mirall-%{version}.tar.bz2
%if 0%{?suse_version} == 1110
Patch0:         cmake.diff
%endif
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
Source1:        owncloud.sh 
Patch1:         autostart_use_wrapper.diff
%endif

BuildRequires:  cmake
BuildRequires:  libocsync-devel
BuildRequires:  oxygen-icon-theme
BuildRequires:  gcc gcc-c++
BuildRequires:  %{qtprefix}libqtkeychain-devel

%if 0%{?fedora_version}
BuildRequires:  iniparser
BuildRequires:  qt4 qt4-devel >= 4.7
BuildRequires:  inetd desktop-file-utils
BuildRequires:  qtwebkit >= 2.2
BuildRequires:  qtwebkit-devel >= 2.2
%endif
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
%if 0%{?suse_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  %{qtprefix}libqt4-devel >= 4.7
BuildRequires:  %{qtprefix}libQtWebKit-devel
BuildRequires:  %{qtprefix}libQtWebKit4
%endif

%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
Requires:       %{qtprefix}libqt4-x11
Requires:       %{qtprefix}libQtWebKit4
%endif
Requires:       libocsync-plugin-owncloud >= 0.90.4
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
# Extra invitation to the party
Requires:	libocsync0 >= 0.90.4
%endif
Requires:       net-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The ownCloud client based on Mirall - github.com/owncloud/mirall

ownCloud client enables you to connect to your private
ownCloud Server. With it you can create folders in your home
directory, and keep the contents of those folders synced with your
ownCloud server. Simply copy a file into the directory and the 
ownCloud Client does the rest.

ownCloud gives your employees anytime, anywhere access to the files
they need to get the job done, whether through this desktop application, 
our mobile apps, the web interface, or other WebDAV clients. With it, 
your employees can easily view and share documents and information 
critical to the business, in a secure, flexible and controlled 
architecture. You can easily extend ownCloud with plug-ins from the 
community, or that you build yourself to meet the requirements of 
your infrastructure and business.

ownCloud - Your Cloud, Your Data, Your Way!  www.owncloud.com

Authors
=======
Duncan Mac-Vicar P. <duncan@kde.org>
Klaas Freitag <freitag@owncloud.com>
Daniel Molkentin <danimo@owncloud.com>

%prep
%setup -q -n mirall-%{version}

%if 0%{?suse_version} == 1110
%patch0 -p1
%endif
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
%patch1 -p1
%endif

%build
export LD_LIBRARY_PATH=%{_prefix}/lib64
export PATH=%{_prefix}/bin:$PATH
mkdir build
pushd build
export CSYNC_DIR=/usr/include/ocsync
cmake .. -DCMAKE_INSTALL_PREFIX=%{_prefix:/usr} -DSYSCONF_INSTALL_DIR=/etc %{cmake_args}
make %{?_smp_mflags} owncloud
popd

%install
pushd build
%make_install
popd

%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
pushd $RPM_BUILD_ROOT/%_bindir
ln -s qt-4.8-env.sh owncloud-wrapper 
popd
mkdir -p $RPM_BUILD_ROOT/usr/share/applications/
cat $RPM_BUILD_ROOT%{_datadir}/applications/owncloud.desktop |sed "s,Exec=.*,Exec=%_bindir/owncloud-wrapper," > $RPM_BUILD_ROOT/usr/share/applications/owncloud.desktop
rm $RPM_BUILD_ROOT%{_datadir}/applications/owncloud.desktop
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor
mv $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/* $RPM_BUILD_ROOT/usr/share/icons/hicolor
mkdir -p $RPM_BUILD_ROOT/usr/bin
install -m 755 %{SOURCE1} $RPM_BUILD_ROOT/usr/bin/owncloud
%endif

%if %{?suse_version:1}0
%suse_update_desktop_file -n owncloud
%endif

%if 0%{?fedora_version}
%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
%endif

%files
%defattr(-,root,root,-)
%doc README.md COPYING
%{_bindir}/owncloud
%{_libdir}/libowncloudsync.so*
%{_datadir}/owncloud
%config /etc/ownCloud
%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?suse_version} == 1110
%{_bindir}/owncloud-wrapper
/usr/share/icons/hicolor
/usr/share/applications/owncloud.desktop
/usr/bin/owncloud
%else
%{_datadir}/icons/hicolor
%{_datadir}/applications/owncloud.desktop
%endif
%changelog
* Mon Oct 21 2013 freitag@owncloud.com
  * Update to final 1.4.2 tarball
  * Do not show the warning icon in the tray (#944)
  * Fix manual proxy support when switching (#1016)
  * Add folder column to detailed sync protocol (#1037)
  * Fix possible endless loop in inotify (#1041)
  * Do not elide the progress text (#1049)
  * Fix high CPU load (#1073)
  * Reconnect if network is unavailable after startup (#1080)
  * Ensure paused folder stays paused when syncing with more than one folder (#1083)
  * Don't show desktop notification when the user doesn't want to (#1093)
  * System tray: Avoid quick flickering up of the ok-icon for the sync prepare state
  * Progress: Do not show progress if nothing is transmitted
  * Progress: Show number of deletes.
  * Fix pause/resume behaviour (#1105)
* Mon Oct  7 2013 danimo@owncloud.com
- RHEL/SLE: Add /usr/bin/owncloud as wrapper where needed, fix autostart
* Mon Oct  7 2013 danimo@owncloud.com
- Reintroduce support for SLE 11 SP2/3, RHEL/CentOS 6
* Thu Sep 26 2013 freitag@owncloud.com
- Removed not longer needed patch.
* Thu Sep 26 2013 freitag@owncloud.com
  * Update to final 1.4.1 tarball.
  * Fixed app name for ownCloud.
  * Translation and documentation fixes.
  * Fixed error display in settings/status dialog, displays multi
    line error messages now correctly.
  * Wait up to 30 secs before complaining about missing systray
    Fixes bug #949
  * Fixed utf8 issues with basic auth authentication, fixes bug #941
  * Fixed remote folder selector, avoid recursive syncing, fixes bug #962
  * Handle and display network problems at startup correctly.
  * Enable and disable the folder watcher during syncs correctly.
  * Fix setting of thread priority.
  * Fixed file size display.
  * Fixed various folder wizard issues, bug #992
  * Made "Sync started" message optional, fixes bug #934
  * Fixed shutdown, avoid crashed config on win32, fixes bug #945
  * Pop up config wizard if no server url is configured, fixes bug #1018
  * Settings: calculate sidebar width dynamically, fixes bug #1020
  * Fixed a crash if sync folders were removed, fixes bug #713
  * Do proper resync after network disconnect, fixes bug #1007
  * Various minor code fixes
* Thu Sep  5 2013 freitag@owncloud.com
- increment build number.
* Thu Sep  5 2013 freitag@owncloud.com
- Added fix translation patch for mirall.
* Thu Sep  5 2013 freitag@owncloud.com
- Fixed runtime dependency version for libocsync
* Wed Sep  4 2013 freitag@owncloud.com
- added some tweaks from the nightly build meta files.
* Wed Sep  4 2013 danimo@owncloud.com
- release of ownCloud Client 1.4.0
  * New Scheduler: Only sync when there are actual changes in the server
  * Add a Settings Dialog, move Proxy Settings there
  * Transform folder Status Dialog into Account Settings, provide feedback via
  * context menu
  * Add Bandwidth Control
  * Add a visual storage/quota indicator (context menu and account settings)
  * Add progress indication (context menu and account settings)
  * Introduce a sync history, persisting results across syncs
  * Move ability to switch to mono icons from a switch to a Settings option
  * Add "Launch on System Startup" GUI option
  * Add "Show Desktop Nofications"GUI option (enabled by default)
    top optionally disable sync notifications
  * Add Help item, pointing to online reference
  * Implement graphical selection of remote folders in FolderWizard
  * Allow custom ignore patterns
  * Add an editor for ingore patterns
  * ALlow to flag certain ignore patterns as discardable
  * Ensure to ship with all valid translations
  * Progress Dialog now preserves the last syncned items across sync runs
  * Split Setup Wizard into multiple pages again
  * Implement "--logfile -" to log to stdout
  * Add preliminary support for Shibboleth authentication
  * Linux: Provide more icon sizes
  * Linux: Do not trigger notifier on ignored files
  * Windows: Reduce priority of CSync thread
  * Documentation: Prem. updates to reflect UI changes
  * Significant code refactorings
  * Require Qt 4.7
  * Known issue: Under certain conditions, a file will only get uploaded after
    up to five minutes
* Tue Jun 25 2013 danimo@owncloud.com
- release of ownCloud Client 1.3.0
  * Default proxy port to 8080
  * Don't lose proxy settings when changing passwords
  * Support SOCKS5 proxy (useful in combination with ssh -D)
  * Propagate proxy changes to csync at runtime
  * Improve proxy wizard
  * Display proxy errors
  * Solved problems with lock files
  * Warn if for some reason all files are scheduled for removal on either side
  * Avoid infinite loop if authentication fails in certain cases
  * Fix reading the password from the config in certain cases
  * Do not crash when configured sync target disappears
  * Make --help work on windows
  * Make sync feedback less ambiguous.
  * Fix icon tray tooltip sometimes showing repeated content
  * More use of native directory separators on Windows
  * Remove journal when reusing a directory that used to have a journal before
  * Visual clean up of status dialog items
  * Wizard: When changing the URL or user name, allow the user to push his data
    to the new location or wipe the folder and start from scratch
  * Wizard: Make setting a custom folder as a sync target work again
  * Fix application icon
  * User-Agent now contains "Mozilla/5.0" and the Platform name (for
  * firewall/proxy compat)
  * Server side directory moves will be detected
  * New setup wizard, defaulting to root syncing (only for new setups)
  * Improved thread stop/termination
* Mon Apr 22 2013 danimo@owncloud.com
- release of ownCloud Client 1.2.5
  * [Fixes] NSIS installer fixes
  * [Fixes] Fix crash race by making certificateChain() thread safe
  * [Fixes] Build with older CMake versions (CentOS/RHEL 6)
  * [Fixes] Wording in GUI
  * [Fixes] Silently ignore "installed = true" status.php
  * Set log verbosity before calling csync_init.
  * GUI feedback for the statistics copy action
  * Safer approach for detecting duplicate sync runs
* Fri Apr 12 2013 danimo@owncloud.com
- Move debian files out of tar ball
* Thu Apr 11 2013 danimo@owncloud.com
- Force explicit dependency for RH/Fedora
* Thu Apr 11 2013 danimo@owncloud.com
- release of ownCloud Client 1.2.4
  * [Fixes] Clarify string in folder wizard
  * [Fixes] Fixed some valgrind warnings
  * [Fixes] Ensure that only one sync thread can ever run
  * [Fixes] Fix default config storage path
  * [Fixes] Skip folders with no absolute path
  * [Fixes] Allow setting the configuration directory on command line
* Tue Apr  2 2013 freitag@owncloud.com
- Fixed specfile, really use version 1.2.3
* Tue Apr  2 2013 freitag@owncloud.com
- release of ownCloud Client 1.2.3
  * [Fixes] Unbreak self-signed certificate handling
* Tue Apr  2 2013 freitag@owncloud.com
- release of ownCloud Client 1.2.2
  * [Fixes] Do not crash when local file tree contains symlinks
  * [Fixes] Correctly handle locked files on Windows
  * [Fixes] Display errors in all members of the SSL chain
  * [Fixes] Enable Accessibility features on Windows
  * [Fixes] Make setupFavLink work properly on Mac OS
  * [Fixes] Ignore temporary files created by MS Office
  * [Gui] Support Nautilus in setupFavLink
* Thu Feb 28 2013 freitag@owncloud.com
- specfile cleanup: Source1 removed, github url added.
* Tue Feb 26 2013 freitag@owncloud.com
- correct version in spec file.
* Tue Feb 26 2013 freitag@owncloud.com
- release of ownCloud Client 1.2.1
  * [Fixes] Leave configured folders on configuration changes.
  * [Fixes] Do not allow to finish the setup dialog if connection can't be established.
  * [Fixes] Better handling of credentials in setup dialog.
  * [Fixes] Do not leak fd's to /dev/null when using gnutls
  * [Fixes] Stop sync scheduling when configuration wizard starts.
  * [Fixes] Clear pending network requests when stepping back in config wizard.
  * [Fixes] User password dialog asynchronous issues.
  * [Fixes] Make folderman starting and stoping the scheduling.
  * [Fixes] Various minor fixes and cleanups.
  * [Fixes] Crash on pausing sync
  * [Fixes] Stale lock file after pausing sync
  * [App] Load translations from app dir or bundle as well.
  * [Platform] Build fixes and simplifications, ie. build only one lib.
  * [Platform] Added some getter/setters for configuration values.
  * [Platform] Added man pages.
  * [Platform] Simplified/fixed credential store usage and custom configs.
  * [Platform] Added soname version to libowncloudsync.
  * [Platform] Pull in Qt translations
  * [Gui]  Make sync result popups less annoyingq
  * [Gui] Fix for result popup
  csync version 0.70.4
  * [Win32] Ship with up-to-date openssl version to fix SSL problems we saw
  * [Fixes] Fix crash during mkdir
  * [Fixes] Added workaround for problem that server sometimes does not
    respond properly to PROPFIND (mirall#285)
  * [Fixes] Fix handling of deletion of non empty or locked directories.
  * [Fixes] Fixed some potential memory leaks
  * [Fixes] Files with filenames with unix extensions are ignored now.
* Thu Feb 21 2013 freitag@owncloud.com
- release of ownCloud Client 1.2.1RC1
* Wed Feb 20 2013 freitag@owncloud.com
- copy over from :devel to :devel:daily.
* Sun Feb  3 2013 freitag@owncloud.com
- Remved extra installed desktop file from deb packages, comes out
  of the source package now.
* Wed Jan 23 2013 freitag@owncloud.com
- Update to version 1.2.0, ocsync 0.70.3 required.
  * [GUI] New status dialog to show a detailed list of synced files.
  * [GUI] New tray notifications about synced files.
  * [GUI] New platform specific icon set.
  * [App] Using cross platform QtKeychain library to store credentials crypted.
  * [App] Use cross platform notification for changes in the local file system rather than regular poll.
  * [Fixes] Improved SSL Certificate handling and SSL fixes troughout syncing.
  * [Fixes] Fixed proxy authentication.
  * [Fixes] Allow brackets in folder name alias.
  * [Fixes] Lots of other minor fixes.
  * [Platform] cmake fixes.
  * [Platform] Improved, more detailed error reporting.
* Thu Jan 17 2013 freitag@owncloud.com
- Fix deb build.
* Thu Jan 17 2013 freitag@owncloud.com
- Fixed building with package desktop file.
* Thu Jan 17 2013 freitag@owncloud.com
- Update to second beta version of 1.2.0
* Fri Dec 21 2012 freitag@owncloud.com
- Update to first beta version of 1.2.0
* Thu Nov 22 2012 freitag@owncloud.com
  version 1.1.2rc (release 2012-11-22), csync 0.60.2 required
  * [Fixes] Allow to properly cancel the password dialog.
  * [Fixes] Share folder name correctly percent encoded with old Qt
    4.6 builds ie. Debian.
  * [Fixes] If local sync dir is not existing, create it.
  * [Fixes] lots of other minor fixes.
  * [GUI] Display error messages in status dialog.
  * [GUI] GUI fixes for the connection wizard.
  * [GUI] Show username for connection in statusdialog.
  * [GUI] Show intro wizard on new connection setup.
  * [APP] Use CredentialStore to better support various credential
    backends.
  * [APP] Handle missing local folder more robust: Create it if
    missing instead of ignoring.
  * [APP] Simplify treewalk code.
  * [Platform] Fix Mac building
* Thu Oct 18 2012 danimo@owncloud.com 
- /etc/owncloud -> /etc/ownCloud
* Thu Oct 18 2012 danimo@owncloud.com 
  version 1.1.1 (release 2012-10-18), csync 0.60.1 required
  * [GUI]   Allow changing folder name in single folder mode
  * [GUI]   Windows: Add license to installer
  * [GUI]   owncloud --logwindow will bring up the log window
    in an already running instance
  * [Fixes] Make sure SSL errors are always handled
  * [Fixes] Allow special characters in folder alias
  * [Fixes] Proper workaround for Menu bug in Ubuntu
  * [Fixes] csync: Fix improper memory cleanup which could
    cause memory leaks and crashes
  * [Fixes] csync: Fix memory leak
  * [Fixes] csync: Allow single quote (') in file names
  * [Fixes] csync: Remove stray temporary files
* Wed Oct 10 2012 freitag@owncloud.com
  version 1.1.0 (release 2012-10-10 ), ocsync 0.60.0 required
  * 
  * [GUI]   Added an about dialog
  * [GUI]   Improved themeing capabilities of the client.
  * [GUI]   Minor fixes in folder assistant.
  * [GUI]   Reworked tray context menu.
  * [GUI]   Users can now sync the server root folder.
  * [Fixes] Proxy support: now supports Proxy Auto-Configuration (PAC)
    on Windows, reliability fixes across all OSes.
  * [Fixes] Url entry field in setup assistant handles http/https correctly.
  * [Fixes] Button enable state in status dialog.
  * [Fixes] Crash fixed on ending the client, tray icon related.
  * [Fixes] Crash through wrong delete operator.
  * [MacOS] behave correctly on retina displays.
  * [MacOS] fix focus policy.
  * [MacOS] Packaging improvements.
  * [MacOS] Packaging improvements.
  * [Platform] Windows: Setup closes client prior to uninstall.
  * [Platform] Windows: ownCloud gets added to autorun by default.
  * [Platform] insert correct version info from cmake.
  * [Platform] csync conf file and database were moved to the users app data
    directory, away from the .csync dir.
  * Renamed exclude.lst to sync-exclude.lst and moved it to
    /etc/appName()/ for more clean packaging. From the user path,
    still exclude.lst is read if sync-exclude.lst is not existing.
  * Placed custom.ini with customization options to /etc/appName()
* Fri Oct  5 2012 freitag@owncloud.com
- Update to v1.1.0beta3 - ocsync 0.50.11 needed
* Thu Sep 20 2012 freitag@owncloud.com
- Update to v1.1.0beta2 - csync 0.50.10 needed
* Fri Aug 31 2012 msrex@owncloud.com
- Update to v1.1.0beta1 - csync 0.50.9 needed
  Required ownCloud v4.5 on the server side
* Tue Aug 14 2012 freitag@owncloud.com
- version 1.0.5 (release 2012-08-14), csync 0.50.8 required
  * [Fixes] Fixed setup dialog: Really use https if checkbox is activated.
* Mon Aug 13 2012 freitag@owncloud.com
- do not remove the unneeded libmirallsync.so to satisfy automatic
  dependency tracking.
* Fri Aug 10 2012 freitag@owncloud.com
- version 1.0.4 (release 2012-08-10), csync 0.50.8 required
  * [APP] ownCloud is now a single instance app, can not start twice any more.
  * [APP] Proxy support
  * [APP] Handle HTTP redirection correctly, note new url.
  * [APP] More relaxed handling of read only directories in the sync paths.
  * [APP] Started to split off a library with sync functionality, eg for KDE
  * [APP] Make ownCloud Info class a singleton, more robust.
  * [GUI] New, simplified connection wizard.
  * [GUI] Added ability for customized theming.
  * [GUI] Improved icon size handling.
  * [GUI] Removed Log Window Button, log available through command line.
  * [GUI] Proxy configuration dialog added.
  * [GUI] Added Translations to languages Slovenian, Polish, Catalan,
    Portuguese (Brazil), German, Greek, Spanish, Czech, Italian, Slovak,
    French, Russian, Japanese, Swedish, Portuguese (Portugal)
    all with translation rate >90%%.
  * [Fixes] Loading of self signed certs into Networkmanager (#oc-843)
  * [Fixes] Win32: Handle SSL dll loading correctly.
  * [Fixes] Many other small fixes and improvements.
* Wed Jul 18 2012 freitag@owncloud.com
- Fixed version in the desktop file
* Fri Jun 22 2012 freitag@owncloud.com
- version 1.0.3 (release 2012-06-19), csync 0.50.7 required
  * [GUI] Added a log window which catches the logging if required and
    allows to save for information.
  * [CMI] Added options --help, --logfile and --logflush
  * [APP] Allow to specify sync frequency in the config file.
  * [Fixes] Do not use csync database files from a sync before.
  * [Fixes] In Connection wizard, write the final config onyl if
    the user really accepted. Also remove the former database.
  * [Fixes] Allow special characters in the sync directory names
  * [Fixes] Win32: Fixed directory removal with special character dirs.
  * [Fixes] MacOS: Do not flood the system log any more
  * [Fixes] MacOS: Put app translations to correct places
  * [Fixes] Win32: Fix loading of csync state db.
  * [Fixes] Improved some english grammar.
  * [Platform] Added krazy2 static code checks.
* Wed May 16 2012 freitag@owncloud.com
- version 1.0.2 (release 18.5.2012), csync 0.50.6 required
  * [GUI] New icon set for ownCloud client
  * [GUI] No splashscreen any more (oC Bug #498)
  * [GUI] Russian translation added
  * [GUI] Added 'open ownCloud' to traymenu
  * [GUI] "Pause" and "Resume" instead of Enable/Disable
  * [Fixes] Long running syncs can be interrupted now.
  * [Fixes] Dialogs comes to front on click
  * [Fixes] Open local sync folder from tray and status for win32
  * [Fixes] Load exclude.lst correctly on MacOSX
* Fri May 11 2012 freitag@owncloud.com
- updated tarball to beta of next release 1.0.2
* Thu May 10 2012 msrex@owncloud.com
- updated debian dependencies around time syncing
* Tue May  1 2012 msrex@owncloud.com
- Correct installation of .desktop file in debian
* Fri Apr 20 2012 msrex@owncloud.com
- change dependencies again on non-SUSE platforms
* Thu Apr 19 2012 msrex@owncloud.com
- fix dependency for libiniparser on non-SUSE platforms
* Wed Apr 18 2012 freitag@opensuse.org
- version 1.0.1 (release 2012-04-18), csync 0.50.5 required
  * [Security] Support SSL Connections
  * [Security] SSL Warning dialog
  * [Security] Do not store password in clear text anymore
  * [Security] Restrict credentials to the configured host
  * [Security] Added ability to forbid local password storage.
  * [Fixes] Various fixes of the startup behaviour.
  * [Fixes] Various fixes in sync status display
  * [GUI] Various error messages for user display improved.
  * [GUI] fixed terms and Translations
  * [GUI] fixed translation loading
  * [Intern] Migrate old credentials to new format
  * [Intern] Some code refactorings, got rid of rotten QWebDav lib
  * [Intern] lots of cmake cleanups
  * [Platform] MacOSX porting efforts
  * [Platform] MacOSX Bundle creation added
  * [Platform] Enabled ranslations on Windows.
* Wed Apr 18 2012 msrex@owncloud.com
- fix typo in debian dependencies
* Wed Apr 18 2012 msrex@owncloud.com
- more debian / ubuntu packaging
* Wed Apr 18 2012 msrex@owncloud.com
- add debian / ubuntu packaging
* Tue Apr  3 2012 freitag@opensuse.org
- removed requirement on rubygem, not needed for this client.
* Mon Apr  2 2012 msrex@suse.de
- change minimum csync version required
* Mon Apr  2 2012 freitag@opensuse.org
- update to version 1.0.0
* Sun Apr  1 2012 msrex@owncloud.com
- renamed package mirall to owncloud-client
- new descriptions
